#   Copyright 2017 Red Hat, Inc. All Rights Reserved.
#
#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
"""
ARA: Ansible Run Analysis
"""

import pbr.version

# Setup version
VERSION = pbr.version.VersionInfo('ara')
try:
    __version__ = VERSION.version_string()
    __release__ = VERSION.release_string()
except (ValueError, AttributeError):
    __version__ = None
    __release__ = None
